@@ -235,6 +235,41 @@ class OccurrenceDeleteViewTestCase(
     def test_deletion(self):
         self.is_callable(method='post')
 
+        self.is_callable(kwargs={
+            'pk': self.event.pk,
+            'year': self.event.start.date().year,
+            'month': self.event.start.date().month,
+            'day': self.event.start.date().day + 1,
+        }, message=('Should be callable, if date in period.'))
+
+        self.is_not_callable(kwargs={
+            'pk': 5,
+            'year': self.event.start.date().year,
+            'month': self.event.start.date().month,
+            'day': self.event.start.date().day,
+        }, message=('Wrong event pk.'))
+
+        self.is_not_callable(kwargs={
+            'pk': self.event.pk,
+            'year': self.event.start.date().year,
+            'month': '999',
+            'day': self.event.start.date().day,
+        }, message=('Wrong dates.'))
+
+        new_rule = RuleFactory(name='weekly', frequency='WEEKLY')
+        new_event = EventFactory(
+            rule=new_rule,
+            end_recurring_period=now() + timedelta(days=200),
+            set__start=-5,
+        )
+        test_date = self.event.start.date() - timedelta(days=1)
+        self.is_not_callable(kwargs={
+            'pk': new_event.pk,
+            'year': test_date.year,
+            'month': test_date.month,
+            'day': test_date.day,
+        }, message=('No occurrence available for this day.'))
+
 
 class OccurrenceDetailViewTestCase(
         OccurrenceViewTestCaseMixin, ViewTestMixin, TestCase):
@@ -248,3 +283,25 @@ class OccurrenceUpdateViewTestCase(
     """Tests for the ``OccurrenceUpdateView`` view class."""
     def get_view_name(self):
         return 'calendar_occurrence_update'
+
+
+class UpcomingEventsAjaxViewTestCase(ViewTestMixin, TestCase):
+    """Tests for the ``UpcomingEventsAjaxView`` view class."""
+    def get_view_name(self):
+        return 'calendar_upcoming_events'
+
+    def test_view(self):
+        self.should_be_callable_when_anonymous()
+
+    def test_view_with_count(self):
+        url = self.get_url()
+        url = url + '?count=5'
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
+
+    def test_view_with_category(self):
+        cat = EventCategoryFactory()
+        url = self.get_url()
+        url = url + '?category={0}'.format(cat.slug)
+        resp = self.client.get(url)
+        self.assertEqual(resp.status_code, 200)
